﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;


public class BaseShip : MonoBehaviour
{
    public GameController gameController;
    public GameEntityType type;

    public float healthPoints;
    public float totalHealthPoints;
    public float moveSpeed;
    public float shootingRate;

    public List<GameObject> canonList;
    public ParticleSystem explosion;
    /// <summary>
    /// Blink logic
    /// </summary>
    public bool blink = false;
    public bool alive = true;

    public void RecieveDamage(float damage)
    {
        healthPoints -= damage;
    }
    /// <summary>
    /// If object is alive blinks for blinkTime seconds
    /// </summary>
    /// <param name="blinkTime">blink time in seconds</param>
    /// <returns></returns>
    public IEnumerator Blink(float blinkTime)
    {
        if (alive)
        {
            if (!blink)
            {
                blink = true;
                Color oldColor = gameObject.GetComponentInChildren<SpriteRenderer>().color;
                gameObject.GetComponentInChildren<SpriteRenderer>().color = Color.black;
                yield return new WaitForSeconds(blinkTime);
                if (alive)  //this needs to be checked again because its executed concurently in yield and if the object is destroyed in produces an error
                {
                    gameObject.GetComponentInChildren<SpriteRenderer>().color = oldColor;
                }
                blink = false;
            }
        }

    }
    public void InitGameController()
    {
        GameObject gameControllerObject = GameObject.FindWithTag("GameController");
        if (gameControllerObject != null)
        {
            gameController = gameControllerObject.GetComponent<GameController>();
        }
        if (gameController == null)
        {
            Debug.Log(name + " Cannot find 'GameController' script");
        }
    }
}
