﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

[System.Serializable]
public class Boundary
{
    public float xMin, xMax, yMin, yMax;
}

public class PlayerController : BaseShip
{
    new Rigidbody2D rigidbody;
    public Boundary boundary;

    //Shooting logic

    public GameObject projectile;
    public GameObject canon;
    private float nextShot;
    public float minSpeed;
    public float maxSpeed;
    public AudioSource recieveDamageSound;
    public Vector2 velocityDebug;
    // Use this for initialization
    void Start()
    {
        InitGameController();
        rigidbody = GetComponent<Rigidbody2D>();
        type = GameEntityType.PlayerShip;
        canon = transform.FindChild("CentralCanon").gameObject;

    }
    void Update()
    {
        if (gameController.gameState == GameState.Playing)
        {
            if (alive)
            {
                if (healthPoints <= 0)
                {
                    Die();
                }

                PrimaryShoot();

            }
        }
    }

    void FixedUpdate()
    {
        if (gameController.gameState == GameState.Playing)
        {
            Move();
        }
    }

    /// <summary>
    /// Move player using unity Input
    /// </summary>
    public void Move()
    {
        float moveHorizontal = Input.GetAxis("Horizontal");
        float moveVertical = Input.GetAxis("Vertical");

        Vector2 movement = new Vector2(Mathf.Clamp(moveHorizontal * moveSpeed, minSpeed, maxSpeed), Mathf.Clamp(moveVertical * moveSpeed, minSpeed, maxSpeed));
        rigidbody.velocity = movement;  //rigidbody.AddForce(new Vector2(moveHorizontal, moveVertical));
        velocityDebug = movement;
        rigidbody.position = new Vector2
       (
           Mathf.Clamp(rigidbody.position.x, boundary.xMin, boundary.xMax),
           Mathf.Clamp(rigidbody.position.y, boundary.yMin, boundary.yMax)

       );
    }
    /// <summary>
    /// Shoot primary canon using projectiles
    /// </summary>
    public void PrimaryShoot()
    {

        if (Input.GetButton("Fire1") && Time.time > nextShot)
        {
            nextShot = Time.time + shootingRate;
            GameObject newProjectile = (GameObject)Instantiate(projectile, canon.transform.position, canon.transform.rotation);
            newProjectile.transform.GetComponent<PlayerProjectileController>().SetPlayerAsParent();
            //newProjectile.transform.GetComponent<PlayerProjectileController>().SetPlayerStraightSine();
        }
    }
    public void Die()
    {
        alive = false;
        transform.FindChild("MainSprite").gameObject.SetActive(false);
        Instantiate(explosion, transform.position, transform.rotation);
    }

    private void OnTriggerEnter2D(Collider2D collision)
    {

        GameObject collidedWith = collision.gameObject;//collision.gameObject.name;

        if (collidedWith.GetComponent<BaseShip>() != null)
        {
            if (collidedWith.GetComponent<BaseShip>().type == GameEntityType.EnemyShip)
            {

                //If player collides with enemy,player recieves damage with value of enemyHP
                RecieveDamage(gameController.fixedEnemyDamage);
                recieveDamageSound.Play();

            }
        }

        if (collidedWith.tag == "Barier")
        {
            RecieveDamage(healthPoints);
        }
        //enalbe use full kinematic contacts for it to work
    }
}
